import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import React from 'react';
import { mount } from 'enzyme';
import { Overlay } from '..';
describe('Overlay', function () {
  it('should change z-index when using z-index prop', function () {
    var wrapper = mount( /*#__PURE__*/React.createElement(Overlay, {
      visible: true,
      zIndex: 99
    }));
    var overlay = wrapper.find('.rc-overlay');
    expect(overlay.getDOMNode().style.zIndex).toEqual('99');
  });
  it('should allow to custom class name with class-name prop', function () {
    var wrapper = mount( /*#__PURE__*/React.createElement(Overlay, {
      visible: true,
      className: "foo"
    }));
    var overlay = wrapper.find('.rc-overlay');
    expect(overlay.contains('foo'));
  });
  it('should allow to custom style with custom-style prop', function () {
    var wrapper = mount( /*#__PURE__*/React.createElement(Overlay, {
      visible: true,
      customStyle: {
        backgroundColor: 'red'
      }
    }));
    var overlay = wrapper.find('.rc-overlay');
    expect(overlay.getDOMNode().style.backgroundColor).toEqual('red');
  });
  it('should change animation duration when using duration prop', function () {
    var wrapper = mount( /*#__PURE__*/React.createElement(Overlay, {
      visible: true,
      duration: 100
    }));
    var overlay = wrapper.find('.rc-overlay');
    expect(overlay.getDOMNode().style.animationDuration).toEqual('100ms');
  });
  it('should render default slot correctly', function () {
    var wrapper = mount( /*#__PURE__*/React.createElement(Overlay, null, "Custom Default"));
    expect(wrapper).toMatchSnapshot();
  });
  it('should allow to touchmove when lock-scroll is false', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
    var onTouchMove, wrapper, overlay;
    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            onTouchMove = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement("div", {
              onTouchMove: onTouchMove
            }, /*#__PURE__*/React.createElement(Overlay, {
              visible: true,
              lockScroll: false
            })));
            overlay = wrapper.find('.rc-overlay');
            overlay.simulate('touchmove');
            expect(onTouchMove).toHaveBeenCalledTimes(1);

          case 5:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  })));
  it('should not allow to touchmove when lock-scroll is true', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee2() {
    var onTouchMove, wrapper, overlay;
    return _regeneratorRuntime.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            onTouchMove = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement("div", {
              onTouchMove: onTouchMove
            }, /*#__PURE__*/React.createElement(Overlay, {
              visible: true,
              lockScroll: true
            })));
            overlay = wrapper.find('.rc-overlay');
            overlay.simulate('touchmove');
            expect(onTouchMove).toHaveBeenCalledTimes(0);

          case 5:
          case "end":
            return _context2.stop();
        }
      }
    }, _callee2);
  })));
});